@@ -7,7 +7,7 @@
 #include <errno.h>
 #include <functional>
 #include <memory>
-#include "libuv/include/uv.h"
+#include <uv.h>
 #include "base64/base64.hpp"
 #include "uvutil.h"
 #include "webapplication.h"
@@ -500,7 +500,7 @@ std::string doEncodeURI(std::string value, bool encodeReserved) {
     if (!needsEscape(*it, encodeReserved)) {
       os << *it;
     } else {
-      os << '%' << std::setw(2) << static_cast<unsigned int>(static_cast<unsigned char>(*it));
+      os << '%' << std::setw(2) << std::setfill('0') << static_cast<unsigned int>(static_cast<unsigned char>(*it));
     }
   }
   return os.str();
